pub struct Compiler<'a> { /* private fields */ }Expand description
The compiler has many compile_* functions. These all accept a state param which
should contain the type state of the program immediately before the expression
that is being compiled would execute. The state should be modified to reflect the
state after the compiled expression executes. This logic lives in Expression::type_info.
Implementations
Sourceimpl<'a> Compiler<'a>
impl<'a> Compiler<'a>
Sourcepub fn compile(
fns: &'a [Box<dyn Function>],
ast: Program,
state: &TypeState,
config: CompileConfig,
) -> Result<CompilationResult, DiagnosticList>
pub fn compile( fns: &'a [Box<dyn Function>], ast: Program, state: &TypeState, config: CompileConfig, ) -> Result<CompilationResult, DiagnosticList>
Compiles a given source into the final Program.
Arguments
source- A string slice that holds the source code to be compiled.fns- A slice of boxed functions to be used during compilation.
Returns
A Result containing the CompilationResult if successful, or a DiagnosticList if there are errors.
Errors
Any compilation error.