pub struct ProgramInfo {
pub fallible: bool,
pub abortable: bool,
pub target_queries: Vec<OwnedTargetPath>,
pub target_assignments: Vec<OwnedTargetPath>,
}Fields
fallible: boolReturns whether the compiled program can fail at runtime.
A program can only fail at runtime if the fallible-function-call
(foo!()) is used within the source.
abortable: boolReturns whether the compiled program can be aborted at runtime.
A program can only abort at runtime if there’s an explicit abort
statement in the source.
target_queries: Vec<OwnedTargetPath>A list of possible queries made to the external target at runtime.
target_assignments: Vec<OwnedTargetPath>A list of possible assignments made to the external target at
runtime.